searchNodes=[{"doc":"Luminous Luminous is a framework for creating dashboards within Phoenix Live View . It is somewhat inspired by grafana both conceptually and functionally in that: it focuses on time series data (albeit not exclusively) it is organized around panels it is parameterized by a time range it can be parameterized by user-defined variables Dashboards are defined at compile time using elixir code (see Luminous.Dashboard.define/3 ). At runtime, Luminous uses the following javascript libraries (as live view hooks ) for supporting client-side visualizations and interactions with the live view process: chartjs for rendering plots tabulator for rendering tabular data flatpickr for time range selection Features Time range selection and refresh of all dashboard panel queries Asynchronous queries and page updates User-facing variable dropdowns that are available to panel queries Client-side zoom in charts Multiple supported chart types (currently :line and :bar ) Download panel data (CSV, PNG) Stat panels (show single or multiple stats) Table panels Summary statistics in charts Installation The package can be installed from hex.pm as follows: def deps do [ { :luminous , &quot;~&gt; 1.4.1&quot; } ] end In order to be able to use the provided components, the library's javascript and CSS files must be imported to your project: In assets/js/app.js : import { ChartJSHook, TableHook, TimeRangeHook } from &quot;luminous&quot; let Hooks = { TimeRangeHook: new TimeRangeHook(), ChartJSHook: new ChartJSHook(), TableHook: new TableHook() } ... let liveSocket = new LiveSocket(&quot;/live&quot;, Socket, { ... hooks: Hooks }) ... Finally, in assets/css/app.css : @import &quot;../../deps/luminous/dist/luminous.css&quot;; Usage A demo dashboard has been provided that showcases some of Luminous' capabilities. The demo can be inspected live using the project's dev server (run mix dev in the project and then visit this page ). Luminous is a framework in the sense that the luminous client is responsible for specifying queries, variables etc. and Luminous.Live will call the client's code by setting up all the required plumbing. In general, a custom dashboard needs to: implement the Luminous.Variable behaviour for the dashboard-specific variables implement the Luminous.Query behaviour for loading the necessary data that will be visualized in the client implement the Luminous.Dashboard behaviour for determining the default time range for the dashboard and optionally injecting parameters to Luminous.Variable.variable/2 callbacks (see Luminous.Dashboard.parameters/1 ) use the Luminous.Live module for leveraging the live dashboard functionality and capabilities render the dashboard in the view template (only Luminous.Components.dashboard is necessary but the layout can be customized by using directly the various components in Luminous.Components )","ref":"Luminous.html","title":"Luminous","type":"module"},{"doc":"This module contains a set of components that can be used to create a dashboard.","ref":"Luminous.Components.html","title":"Luminous.Components","type":"module"},{"doc":"The dashboard component is responsible for rendering all the necessary elements: title variables time range selector panels Additinally, it registers callbacks for reacting to panel loading states. Attributes dashboard ( Luminous.Dashboard ) (required) panel_data ( :map ) (required)","ref":"Luminous.Components.html#dashboard/1","title":"Luminous.Components.dashboard/1","type":"function"},{"doc":"Attributes panel ( Luminous.Panel ) (required)","ref":"Luminous.Components.html#description/1","title":"Luminous.Components.description/1","type":"function"},{"doc":"This component registers the JS event listeners for the panel spinners.","ref":"Luminous.Components.html#listeners/1","title":"Luminous.Components.listeners/1","type":"function"},{"doc":"This component is responsible for rendering the panel's data. Depending on the panel's type, there will be a different visualization. Attributes panel ( Luminous.Panel ) (required) variables ( :list ) (required) panel_data ( :map ) - not used in table panel. time_range_selector ( Luminous.TimeRangeSelector ) - only for the chart panel.","ref":"Luminous.Components.html#panel/1","title":"Luminous.Components.panel/1","type":"function"},{"doc":"Attributes stats ( :map ) (required)","ref":"Luminous.Components.html#panel_statistics/1","title":"Luminous.Components.panel_statistics/1","type":"function"},{"doc":"This component is responsible for rendering the time range component. It consists of a date range picker and a presets dropdown. Attributes dashboard ( Luminous.Dashboard ) (required)","ref":"Luminous.Components.html#time_range/1","title":"Luminous.Components.time_range/1","type":"function"},{"doc":"This component is responsible for rendering the dropdown of the assigned variable. Attributes variable ( Luminous.Variable ) (required)","ref":"Luminous.Components.html#variable/1","title":"Luminous.Components.variable/1","type":"function"},{"doc":"A dashboard is a high-level component initialized by the dashboard live view. It contains all the necessary dashboard attributes such as the panels, variables and the time range selector. It is initialized at compile time using define/3 and populated at runtime using populate/1 .","ref":"Luminous.Dashboard.html","title":"Luminous.Dashboard","type":"behaviour"},{"doc":"The dashboard uses a TimeRangeSelector and a default time range must be defined.","ref":"Luminous.Dashboard.html#c:default_time_range/1","title":"Luminous.Dashboard.default_time_range/1","type":"callback"},{"doc":"Initialize and return a dashboard at compile time.","ref":"Luminous.Dashboard.html#define/3","title":"Luminous.Dashboard.define/3","type":"function"},{"doc":"The consumer can optionally implement this callback, in case they want to inject custom parameters in other callbacks (e.g. Luminous.Variable.variable/2 ). Those parameters can be used to scope the callback results.","ref":"Luminous.Dashboard.html#c:parameters/1","title":"Luminous.Dashboard.parameters/1","type":"callback"},{"doc":"Returns the LV path for the specific dashboard based on its configuration.","ref":"Luminous.Dashboard.html#path/3","title":"Luminous.Dashboard.path/3","type":"function"},{"doc":"Populate the dashboard's dynamic properties (e.g. variable values, time range etc.) at runtime.","ref":"Luminous.Dashboard.html#populate/2","title":"Luminous.Dashboard.populate/2","type":"function"},{"doc":"Update the dashboard's current time range with a new one.","ref":"Luminous.Dashboard.html#update_current_time_range/2","title":"Luminous.Dashboard.update_current_time_range/2","type":"function"},{"doc":"Update the dashboard's variables with a new list.","ref":"Luminous.Dashboard.html#update_variables/2","title":"Luminous.Dashboard.update_variables/2","type":"function"},{"doc":"","ref":"Luminous.Dashboard.html#t:t/0","title":"Luminous.Dashboard.t/0","type":"type"},{"doc":"This module demonstrates the functionality of a dashboard using Luminous.Live .","ref":"Luminous.Dashboards.DemoDashboardLive.html","title":"Luminous.Dashboards.DemoDashboardLive","type":"module"},{"doc":"This is where we implement the Luminous.Query behaviour, i.e. all queries that will be visualized in the dashboard's panels (a panel can have multiple queries). All queries have access to the current dashboard variable values and the selected time range. All queries must return a Luminous.Query.Result with optional attributes that specify the visual characteristics of the particular data set (see Luminous.Query.Attributes ). More details in Luminous.Query .","ref":"Luminous.Dashboards.DemoDashboardLive.Queries.html","title":"Luminous.Dashboards.DemoDashboardLive.Queries","type":"module"},{"doc":"This is where we implement the Luminous.Variable behaviour, i.e. define the dashboard's variables displayed as dropdowns in the view The first value in each list is the default one. Values can be either simple (a single binary) or descriptive (label different than the value). Variables values are available within queries where they can serve as parameters. More details in Luminous.Variable .","ref":"Luminous.Dashboards.DemoDashboardLive.Variables.html","title":"Luminous.Dashboards.DemoDashboardLive.Variables","type":"module"},{"doc":"This module contains a macro that contains the functionality of a dashboard LiveView. For more information see Luminous.Dashboards.DemoDashboardLive .","ref":"Luminous.Live.html","title":"Luminous.Live","type":"module"},{"doc":"A panel represents a single visual element (chart) in a dashboard contains many queries.","ref":"Luminous.Panel.html","title":"Luminous.Panel","type":"behaviour"},{"doc":"Initialize a panel at compile time.","ref":"Luminous.Panel.html#define/5","title":"Luminous.Panel.define/5","type":"function"},{"doc":"Returns the DOM id of the given panel.","ref":"Luminous.Panel.html#dom_id/1","title":"Luminous.Panel.dom_id/1","type":"function"},{"doc":"","ref":"Luminous.Panel.html#is_panel/1","title":"Luminous.Panel.is_panel/1","type":"macro"},{"doc":"Refresh all panel queries.","ref":"Luminous.Panel.html#refresh/3","title":"Luminous.Panel.refresh/3","type":"function"},{"doc":"transform a query result to view data acc. to the panel type","ref":"Luminous.Panel.html#c:transform/1","title":"Luminous.Panel.transform/1","type":"callback"},{"doc":"","ref":"Luminous.Panel.html#t:panel_type/0","title":"Luminous.Panel.panel_type/0","type":"type"},{"doc":"","ref":"Luminous.Panel.html#t:t/0","title":"Luminous.Panel.t/0","type":"type"},{"doc":"","ref":"Luminous.Panel.Chart.html","title":"Luminous.Panel.Chart","type":"module"},{"doc":"","ref":"Luminous.Panel.Chart.html#statistics/2","title":"Luminous.Panel.Chart.statistics/2","type":"function"},{"doc":"","ref":"Luminous.Panel.Stat.html","title":"Luminous.Panel.Stat","type":"module"},{"doc":"","ref":"Luminous.Panel.Table.html","title":"Luminous.Panel.Table","type":"module"},{"doc":"A query is embedded in a panel and contains a function which will be executed upon panel refresh to fetch the query's data.","ref":"Luminous.Query.html","title":"Luminous.Query","type":"behaviour"},{"doc":"Initialize a query at compile time. The module must implement the Luminous.Query behaviour.","ref":"Luminous.Query.html#define/2","title":"Luminous.Query.define/2","type":"function"},{"doc":"Execute the query and return the data as multiple TimeSeries structs.","ref":"Luminous.Query.html#execute/3","title":"Luminous.Query.execute/3","type":"function"},{"doc":"A module must implement this behaviour to be passed as an argument to Luminous.Query.define/2 . A query must return a list of 2-tuples: the 2-tuple's first element is the time series' label the 2-tuple's second element is the label's value the list must contain a 2-tuple with the label :time and a DateTime value.","ref":"Luminous.Query.html#c:query/3","title":"Luminous.Query.query/3","type":"callback"},{"doc":"","ref":"Luminous.Query.html#t:t/0","title":"Luminous.Query.t/0","type":"type"},{"doc":"This struct collects all the attributes that apply to a particular Dataset. It is specified in the attrs argument of Luminous.Query.Result.new/2 .","ref":"Luminous.Query.Attributes.html","title":"Luminous.Query.Attributes","type":"module"},{"doc":"","ref":"Luminous.Query.Attributes.html#define/0","title":"Luminous.Query.Attributes.define/0","type":"function"},{"doc":"","ref":"Luminous.Query.Attributes.html#define/1","title":"Luminous.Query.Attributes.define/1","type":"function"},{"doc":"","ref":"Luminous.Query.Attributes.html#t:decimal_precision/0","title":"Luminous.Query.Attributes.decimal_precision/0","type":"type"},{"doc":"","ref":"Luminous.Query.Attributes.html#t:t/0","title":"Luminous.Query.Attributes.t/0","type":"type"},{"doc":"","ref":"Luminous.Query.Attributes.html#t:totals_function/0","title":"Luminous.Query.Attributes.totals_function/0","type":"type"},{"doc":"A query Result wraps a columnar data frame with multiple variables. attrs is a map where keys are variable labels (as specified in the query's select statement) and values are keyword lists with visualization properties for the corresponding DataSet . See Luminous.Query.DataSet.new/3 for details.","ref":"Luminous.Query.Result.html","title":"Luminous.Query.Result","type":"module"},{"doc":"This function can be called in the following ways: with a list of rows, i.e. a list of lists containing 2-tuples {label, value} with a single row, i.e. a list of 2-tuples of the form {label, value} (e.g. in the case of single- or multi- stats) with a single value (for use in a single-valued stat panel with no label)","ref":"Luminous.Query.Result.html#new/2","title":"Luminous.Query.Result.new/2","type":"function"},{"doc":"","ref":"Luminous.Query.Result.html#t:label/0","title":"Luminous.Query.Result.label/0","type":"type"},{"doc":"","ref":"Luminous.Query.Result.html#t:point/0","title":"Luminous.Query.Result.point/0","type":"type"},{"doc":"","ref":"Luminous.Query.Result.html#t:row/0","title":"Luminous.Query.Result.row/0","type":"type"},{"doc":"","ref":"Luminous.Query.Result.html#t:t/0","title":"Luminous.Query.Result.t/0","type":"type"},{"doc":"","ref":"Luminous.Query.Result.html#t:value/0","title":"Luminous.Query.Result.value/0","type":"type"},{"doc":"This module defines a struct with two fields ( :from and :to ) to represent a time range. Additionally, various helper functions are defined that operate on time ranges.","ref":"Luminous.TimeRange.html","title":"Luminous.TimeRange","type":"module"},{"doc":"","ref":"Luminous.TimeRange.html#add/3","title":"Luminous.TimeRange.add/3","type":"function"},{"doc":"","ref":"Luminous.TimeRange.html#from_iso/2","title":"Luminous.TimeRange.from_iso/2","type":"function"},{"doc":"","ref":"Luminous.TimeRange.html#from_unix/2","title":"Luminous.TimeRange.from_unix/2","type":"function"},{"doc":"","ref":"Luminous.TimeRange.html#last_month/2","title":"Luminous.TimeRange.last_month/2","type":"function"},{"doc":"","ref":"Luminous.TimeRange.html#last_n_days/3","title":"Luminous.TimeRange.last_n_days/3","type":"function"},{"doc":"","ref":"Luminous.TimeRange.html#last_week/2","title":"Luminous.TimeRange.last_week/2","type":"function"},{"doc":"","ref":"Luminous.TimeRange.html#new/2","title":"Luminous.TimeRange.new/2","type":"function"},{"doc":"","ref":"Luminous.TimeRange.html#round/2","title":"Luminous.TimeRange.round/2","type":"function"},{"doc":"","ref":"Luminous.TimeRange.html#shift_zone!/2","title":"Luminous.TimeRange.shift_zone!/2","type":"function"},{"doc":"","ref":"Luminous.TimeRange.html#this_month/2","title":"Luminous.TimeRange.this_month/2","type":"function"},{"doc":"","ref":"Luminous.TimeRange.html#this_week/2","title":"Luminous.TimeRange.this_week/2","type":"function"},{"doc":"","ref":"Luminous.TimeRange.html#to_map/1","title":"Luminous.TimeRange.to_map/1","type":"function"},{"doc":"","ref":"Luminous.TimeRange.html#today/2","title":"Luminous.TimeRange.today/2","type":"function"},{"doc":"","ref":"Luminous.TimeRange.html#tomorrow/2","title":"Luminous.TimeRange.tomorrow/2","type":"function"},{"doc":"","ref":"Luminous.TimeRange.html#yesterday/2","title":"Luminous.TimeRange.yesterday/2","type":"function"},{"doc":"","ref":"Luminous.TimeRange.html#t:t/0","title":"Luminous.TimeRange.t/0","type":"type"},{"doc":"A selector represents the widget in the dashboard that allows for selecting a time range/period. It is defined at compile time and populated at compile time (current value). It can also be updated with a new value.","ref":"Luminous.TimeRangeSelector.html","title":"Luminous.TimeRangeSelector","type":"module"},{"doc":"Calculates and returns the time range for the given preset in the given time zone.","ref":"Luminous.TimeRangeSelector.html#get_time_range_for/2","title":"Luminous.TimeRangeSelector.get_time_range_for/2","type":"function"},{"doc":"","ref":"Luminous.TimeRangeSelector.html#hook/0","title":"Luminous.TimeRangeSelector.hook/0","type":"function"},{"doc":"","ref":"Luminous.TimeRangeSelector.html#id/0","title":"Luminous.TimeRangeSelector.id/0","type":"function"},{"doc":"Populate the selector's dynamic properties (e.g. current time range) at runtime.","ref":"Luminous.TimeRangeSelector.html#populate/2","title":"Luminous.TimeRangeSelector.populate/2","type":"function"},{"doc":"Returns a list with the available time range presets.","ref":"Luminous.TimeRangeSelector.html#presets/0","title":"Luminous.TimeRangeSelector.presets/0","type":"function"},{"doc":"Updates the current time range of the selector.","ref":"Luminous.TimeRangeSelector.html#update_current/2","title":"Luminous.TimeRangeSelector.update_current/2","type":"function"},{"doc":"","ref":"Luminous.TimeRangeSelector.html#t:preset/0","title":"Luminous.TimeRangeSelector.preset/0","type":"type"},{"doc":"","ref":"Luminous.TimeRangeSelector.html#t:t/0","title":"Luminous.TimeRangeSelector.t/0","type":"type"},{"doc":"","ref":"Luminous.TimeRangeSelector.html#t:time_zone/0","title":"Luminous.TimeRangeSelector.time_zone/0","type":"type"},{"doc":"A variable is defined at compile time and its values are determined at runtime. It also stores a current value that can be updated. A variable value is descriptive in that it contains a label (for display purposes) and the actual value.","ref":"Luminous.Variable.html","title":"Luminous.Variable","type":"behaviour"},{"doc":"Defines a new variable and returns the struct does not calculate the values yet (see populate/1 ). The module must implement the Luminous.Variable behaviour.","ref":"Luminous.Variable.html#define/3","title":"Luminous.Variable.define/3","type":"function"},{"doc":"Extracts and returns the label from the descriptive variable value.","ref":"Luminous.Variable.html#extract_label/1","title":"Luminous.Variable.extract_label/1","type":"function"},{"doc":"Extract and returns the value from the descriptive variable value.","ref":"Luminous.Variable.html#extract_value/1","title":"Luminous.Variable.extract_value/1","type":"function"},{"doc":"Find and return the variable with the specified id in the supplied variables.","ref":"Luminous.Variable.html#find/2","title":"Luminous.Variable.find/2","type":"function"},{"doc":"Returns the variable's current (descriptive) value or nil .","ref":"Luminous.Variable.html#get_current/1","title":"Luminous.Variable.get_current/1","type":"function"},{"doc":"Find the variable with the supplied id in the supplied variables and return its current extracted value.","ref":"Luminous.Variable.html#get_current_and_extract_value/2","title":"Luminous.Variable.get_current_and_extract_value/2","type":"function"},{"doc":"Uses the query to populate the variables's values and returns the new struct. Additionally, it sets the current value to be the first of the calculated values.","ref":"Luminous.Variable.html#populate/2","title":"Luminous.Variable.populate/2","type":"function"},{"doc":"Replaces the variables current value with the new value and returns the new struct. It performs a check whether the supplied value is a valid value (i.e. exists in values). If it's not, then it returns the struct unchanged.","ref":"Luminous.Variable.html#update_current/2","title":"Luminous.Variable.update_current/2","type":"function"},{"doc":"A module must implement this behaviour to be passed as an argument to define/3 .","ref":"Luminous.Variable.html#c:variable/2","title":"Luminous.Variable.variable/2","type":"callback"},{"doc":"","ref":"Luminous.Variable.html#t:descriptive_value/0","title":"Luminous.Variable.descriptive_value/0","type":"type"},{"doc":"","ref":"Luminous.Variable.html#t:simple_value/0","title":"Luminous.Variable.simple_value/0","type":"type"},{"doc":"","ref":"Luminous.Variable.html#t:t/0","title":"Luminous.Variable.t/0","type":"type"},{"doc":"Luminous Luminous is a framework for creating dashboards within Phoenix Live View . It is somewhat inspired by grafana both conceptually and functionally in that: it focuses on time series data (albeit not exclusively) it is organized around panels it is parameterized by a time range it can be parameterized by user-defined variables Dashboards are defined at compile time using elixir code (see Luminous.Dashboard.define/3 ). At runtime, Luminous uses the following javascript libraries (as live view hooks ) for supporting client-side visualizations and interactions with the live view process: chartjs for rendering plots tabulator for rendering tabular data flatpickr for time range selection","ref":"readme.html","title":"README","type":"extras"},{"doc":"Time range selection and refresh of all dashboard panel queries Asynchronous queries and page updates User-facing variable dropdowns that are available to panel queries Client-side zoom in charts Multiple supported chart types (currently :line and :bar ) Download panel data (CSV, PNG) Stat panels (show single or multiple stats) Table panels Summary statistics in charts","ref":"readme.html#features","title":"README - Features","type":"extras"},{"doc":"The package can be installed from hex.pm as follows: def deps do [ { :luminous , &quot;~&gt; 1.4.1&quot; } ] end In order to be able to use the provided components, the library's javascript and CSS files must be imported to your project: In assets/js/app.js : import { ChartJSHook, TableHook, TimeRangeHook } from &quot;luminous&quot; let Hooks = { TimeRangeHook: new TimeRangeHook(), ChartJSHook: new ChartJSHook(), TableHook: new TableHook() } ... let liveSocket = new LiveSocket(&quot;/live&quot;, Socket, { ... hooks: Hooks }) ... Finally, in assets/css/app.css : @import &quot;../../deps/luminous/dist/luminous.css&quot;;","ref":"readme.html#installation","title":"README - Installation","type":"extras"},{"doc":"A demo dashboard has been provided that showcases some of Luminous' capabilities. The demo can be inspected live using the project's dev server (run mix dev in the project and then visit this page ). Luminous is a framework in the sense that the luminous client is responsible for specifying queries, variables etc. and Luminous.Live will call the client's code by setting up all the required plumbing. In general, a custom dashboard needs to: implement the Luminous.Variable behaviour for the dashboard-specific variables implement the Luminous.Query behaviour for loading the necessary data that will be visualized in the client implement the Luminous.Dashboard behaviour for determining the default time range for the dashboard and optionally injecting parameters to Luminous.Variable.variable/2 callbacks (see Luminous.Dashboard.parameters/1 ) use the Luminous.Live module for leveraging the live dashboard functionality and capabilities render the dashboard in the view template (only Luminous.Components.dashboard is necessary but the layout can be customized by using directly the various components in Luminous.Components )","ref":"readme.html#usage","title":"README - Usage","type":"extras"},{"doc":"luminous provides CSS classes that can be overriden, so that the components match the look and feel of the consumer application. Those classes belong to three luminous components: Variables Time range selector Panel dropdown Variables lmn-variable-button Define the size, shape, background color, on hover behavior, etc. of the variable buttons. lmn-variable-button-label Define the font, text size, weight, alignment of the variable button's label. lmn-variable-button-label-prefix Define the font, text size, weight, alignment of the variable button's label prefix. lmn-variable-button-icon Define the size and alignment of the variable button's chevron icon. lmn-variable-dropdown Define the size, background color, rouding, shadows, etc. of the variable dropdown menu. lmn-variable-dropdown-item-container Define the text alignment, rounding, on hover behaviour, etc. of each item in the variable dropdown menu. lmn-variable-dropdown-item-content Define the size, padding, etc. of the content of each item in the variable dropdown menu. Time range picker lmn-time-range-compound Define the structure of the time range component. This includes the time range picker button, the pressets button and the time zone component. lmn-time-range-selector Define the structure, the size and the shape of the time range selector component. This includes the button that opens the custom time range selector and the button that opens the preset menu dropdown. lmn-custom-time-range-input Define the size, background color, text size, on hover behavior, etc. of the button that opens the custom date range picker dropdown. lmn-time-range-presets-button Define the size, background color, on hover behavior, etc. of the button that opens the time range presets dropdown. lmn-time-range-presets-button-icon Define the size and spacing of the icon in the button that opens the time range presets dropdown. lmn-time-range-presets-dropdown Define the size, background color, rouding, shadows, etc. of the time range presets dropdown menu. lmn-time-range-presets-dropdown-item-container Define the text alignment, rounding, on hover behaviour, etc. of each item in the time range presets dropdown menu. lmn-time-range-presets-dropdown-item-content Define the size, padding, etc. of the content of each item in the time range presets dropdown menu. lmn-time-zone Define the background color, rounding, text size, etc. of the time zone label Panel dropdown lmn-panel-actions-dropdown Define the size, background color, rouding, shadows, etc. of the panel actions dropdown menu. lmn-panel-actions-dropdown-item-container Define the text alignment, rounding, on hover behaviour, etc. of each item in the panel actions dropdown menu. lmn-panel-actions-dropdown-item-content Define the size, padding, etc. of the content of each item in the panel actions dropdown menu. Dropdown transition lmn-dropdown-transition-enter Define the animation of all dropdowns when they open up. lmn-dropdown-transition-start Define the initial state of the animation of all dropdowns when they open up. lmn-dropdown-transition-end Define the final state of the animation of all dropdowns when they open up. Calendar dropdown For the calendar dropdown, by default we use the airbnb theme provided by flatpickr . To change this theme, you have to import the desired theme after importing luminous to your app.css file like so: @import 'luminous/dist/luminous'; @import '../node_modules/flatpickr/dist/themes/material_blue.css'; The path that the flatpickr theme resides, depends on your project's directory structure.","ref":"applying-custom-css.html","title":"Applying custom CSS","type":"extras"}]